==> brkout-0.1.tar.gz: brkout-0.1/title.c <==
#include <kos.h>
#include <png/png.h>
#include "brkout.h"
#include "title.h"

static pvr_poly_hdr_t title_header;
static pvr_poly_hdr_t ballsel_header;
static int menu_choice;
static int cht = 0;

static void draw_title(float a);
static void title_render(float a);

static uint16 cbtn[] = { CONT_X, 0, CONT_Y, 0, CONT_B, 0, CONT_B, 0, CONT_Y, -1 };  

int title_screen(void) {
	int i;
	static pvr_ptr_t title_txr = 0;
	static pvr_ptr_t ballsel_txr = 0;
	uint32 bw, bh;
	uint32 ballsel_compat;
	pvr_poly_cxt_t tmp_cxt;
	cont_cond_t cond, last_cond;
	float a = 1.0f;
	int cidx = 0;

	/* Should probably verify ptr is not NULL */
	if (title_txr == NULL) {
		title_txr = pvr_mem_malloc(1024*1024*2);
		/* Have to convert back to uint32 b/c png and twiddle routines use ta_compat */
		if (png_to_texture("/rd/brkout.png", (uint32)title_txr, PNG_NO_ALPHA) < 0) {
			printf("failed to load title screen\n");
			pvr_mem_free(title_txr);
			return -1;
		}
		pvr_poly_cxt_txr(&tmp_cxt, PVR_LIST_OP_POLY, PVR_TXRFMT_RGB565 | PVR_TXRFMT_TWIDDLED,
				1024, 1024, title_txr, PVR_FILTER_NONE);
		pvr_poly_compile(&title_header, &tmp_cxt);
	}

	if (ballsel_txr == NULL) {
		if (png_load_texture("/rd/ballsel.png", &ballsel_compat, PNG_NO_ALPHA, &bw, &bh) < 0) {
			printf("failed to load ballsel\n");
			pvr_mem_free(title_txr);
			return -1;
		}
		ballsel_txr = (pvr_ptr_t)ballsel_compat;
		pvr_poly_cxt_txr(&tmp_cxt, PVR_LIST_OP_POLY, PVR_TXRFMT_RGB565 | PVR_TXRFMT_TWIDDLED,
				bw, bh, ballsel_txr, PVR_FILTER_NONE);
		pvr_poly_compile(&ballsel_header, &tmp_cxt);
	}

	cont_get_cond(maple_controller[0], &last_cond);

	pvr_set_bg_color(0, 0, 0);

	menu_choice = 0;

	for (;;) {

		title_render(a);

		if (cont_get_cond(maple_controller[0], &cond)) {
			/* printf("Error getting controller %d status\n", 0); */
			continue;
		}

		if (!cht) {
			if (cbtn[cidx] == (uint16)-1) {
			snd_sfx_play(SAMPLE_SAVORY, 192, 128); 
			cht ^= 1; 
			} else {
				if (last_cond.buttons != cond.buttons) {
					if (!(cond.buttons & cbtn[cidx])) {
						cidx++;
					} else {
						cidx = 0;
					}
				}
			}
		}
		/* START: start game */
		if (BTN_PRESS(CONT_START) || BTN_PRESS(CONT_A)) {
			snd_sfx_play(SAMPLE_ACTIVATE, 160, 128);
			for (i = 30; i >= 0; i--) title_render(i / 30.0f);
			for (i = 10; i >= 0; i--) title_render(0);
			// pvr_mem_free(title_txr);
			return menu_choice;
		}

		if (BTN_PRESS(CONT_DPAD_UP)) {
			menu_choice--; if (menu_choice < 0) menu_choice = MENU_CHOICES - 1;
			if (menu_choice == 2 && !cht) menu_choice--;
			snd_sfx_play(SAMPLE_SELECT, 160, 128);
		}

		if (BTN_PRESS(CONT_DPAD_DOWN)) {
			menu_choice++; if (menu_choice > MENU_CHOICES - 1) menu_choice = 0;
			if (menu_choice == 2 && !cht) menu_choice++;
			snd_sfx_play(SAMPLE_SELECT, 160, 128);
		}

		last_cond = cond;

	}
/*	pvr_mem_free(title_txr);
	return 0;
	*/
	/* NOTREACHED */

}

void draw_title(float a) {
	pvr_vertex_t vert;
	float x = 0.0f, y = 0.0f, z = 100.0f;
	float dx = 640.0f, dy = 480.0f;
	float r = a, g = a, b = a;

	vert.flags = PVR_CMD_VERTEX;
	vert.x = x;
	vert.y = y + dy;
	vert.z = z;
	vert.u = 0.0f;
	vert.v = dy / 1024.0f;
	/* Though the polygon is opaque, we can fade it out
	 * by modifying the rgb vertex values, rather than alpha. */
	vert.argb = PVR_PACK_COLOR(1.0f, r, g, b);
	vert.oargb = 0;
	pvr_prim(&vert, sizeof(vert));
	
	vert.y = y;
	vert.v = 0.0f;
	pvr_prim(&vert, sizeof(vert));
	
	vert.x = x + dx;
	vert.y = y + dy;
	vert.u = dx / 1024.0f;
	vert.v = dy / 1024.0f;
	pvr_prim(&vert, sizeof(vert));

	vert.flags = PVR_CMD_VERTEX_EOL;
	vert.y = y;
	vert.v = 0.0f;
	pvr_prim(&vert, sizeof(vert));
}


void title_render(float a) {
	static int ballsel_pos[MENU_CHOICES] = { 314, 348, 382, 416 };
	vid_border_color(0,0,0);
	pvr_wait_ready();
	pvr_scene_begin();

	pvr_list_begin(PVR_LIST_OP_POLY);
	/* title screen */
	pvr_prim(&title_header, sizeof(title_header));
	draw_title(a);
	
	if (!cht) { 
		pvr_prim(&op_poly_header, sizeof(op_poly_header)); draw_poly_box(280,380,70,20,200,1,0,0,0);
	}

	/* ball selector */
	pvr_prim(&ballsel_header, sizeof(ballsel_header));
	draw_poly_box(250,ballsel_pos[menu_choice],16,16,200,1,a,a,a);

	pvr_list_finish();

	pvr_list_begin(PVR_LIST_TR_POLY);
	pvr_list_finish();

	pvr_scene_finish();
}

==> brkout-0.1.2.tar.gz: brkout-0.1.2/title.c <==
#include <kos.h>
#include <png/png.h>
#include "brkout.h"
#include "title.h"

static pvr_poly_hdr_t title_header;
static pvr_poly_hdr_t ballsel_header;
static pvr_poly_hdr_t cht_header;
static int menu_choice;
static int cht = 0;

static void draw_title(float a);
static void title_render(float a);

static uint16 cbtn[] = { CONT_X, 0, CONT_Y, 0, CONT_B, 0, CONT_B, 0, CONT_Y, -1 };  

int title_screen(void) {
	int i;
	static pvr_ptr_t title_txr = 0;
	static pvr_ptr_t ballsel_txr = 0;
	static pvr_ptr_t cht_txr = 0;
	uint32 bw, bh;
	uint32 ballsel_compat;
	uint32 cht_compat;
	pvr_poly_cxt_t tmp_cxt;
	cont_cond_t cond, last_cond;
	float a = 1.0f;
	int cidx = 0;

	/* Should probably verify ptr is not NULL */
	if (title_txr == NULL) {
		title_txr = pvr_mem_malloc(1024*512*2);
		/* Have to convert back to uint32 b/c png and twiddle routines use ta_compat */
		if (png_to_texture("/rd/brkout.png", (uint32)title_txr, PNG_NO_ALPHA) < 0) {
			printf("failed to load title screen\n");
			pvr_mem_free(title_txr);
			return -1;
		}
		pvr_poly_cxt_txr(&tmp_cxt, PVR_LIST_OP_POLY, PVR_TXRFMT_RGB565 | PVR_TXRFMT_TWIDDLED,
				1024, 512, title_txr, PVR_FILTER_NONE);
		pvr_poly_compile(&title_header, &tmp_cxt);
	}

	if (ballsel_txr == NULL) {
		if (png_load_texture("/rd/ballsel.png", &ballsel_compat, PNG_MASK_ALPHA, &bw, &bh) < 0) {
			printf("failed to load ballsel.png\n");
			pvr_mem_free(title_txr);
			return -1;
		}
		ballsel_txr = (pvr_ptr_t)ballsel_compat;
		pvr_poly_cxt_txr(&tmp_cxt, PVR_LIST_TR_POLY, PVR_TXRFMT_ARGB1555 | PVR_TXRFMT_TWIDDLED,
				bw, bh, ballsel_txr, PVR_FILTER_NONE);
		pvr_poly_compile(&ballsel_header, &tmp_cxt);
	}

	if (cht_txr == NULL) {
		if (png_load_texture("/rd/cht.png", &cht_compat, PNG_FULL_ALPHA, &bw, &bh) < 0) {
			printf("failed to load cht.png\n");
			pvr_mem_free(title_txr);
			return -1;
		}
		cht_txr = (pvr_ptr_t)cht_compat;
		pvr_poly_cxt_txr(&tmp_cxt, PVR_LIST_TR_POLY, PVR_TXRFMT_ARGB4444 | PVR_TXRFMT_TWIDDLED,
				bw, bh, cht_txr, PVR_FILTER_NONE);
		pvr_poly_compile(&cht_header, &tmp_cxt);
	}

	cont_get_cond(maple_controller[0], &last_cond);

	pvr_set_bg_color(0, 0, 0);

	menu_choice = 0;

	for (;;) {

		title_render(a);

		if (cont_get_cond(maple_controller[0], &cond)) {
			/* printf("Error getting controller %d status\n", 0); */
			continue;
		}

		if (!cht) {
			if (cbtn[cidx] == (uint16)-1) {
			snd_sfx_play(SAMPLE_SAVORY, 192, 128); 
			cht ^= 1; 
			} else {
				if (last_cond.buttons != cond.buttons) {
					if (!(cond.buttons & cbtn[cidx])) {
						cidx++;
					} else {
						cidx = 0;
					}
				}
			}
		}
		/* START: start game */
		if (BTN_PRESS(CONT_START) || BTN_PRESS(CONT_A)) {
			snd_sfx_play(SAMPLE_ACTIVATE, 160, 128);
			for (i = 30; i >= 0; i--) title_render(i / 30.0f);
			for (i = 10; i >= 0; i--) title_render(0);
			// pvr_mem_free(title_txr);
			return menu_choice;
		}

		if (BTN_PRESS(CONT_DPAD_UP)) {
			menu_choice--; if (menu_choice < 0) menu_choice = MENU_CHOICES - 1;
			if (menu_choice == 2 && !cht) menu_choice--;
			snd_sfx_play(SAMPLE_SELECT, 160, 128);
		}

		if (BTN_PRESS(CONT_DPAD_DOWN)) {
			menu_choice++; if (menu_choice > MENU_CHOICES - 1) menu_choice = 0;
			if (menu_choice == 2 && !cht) menu_choice++;
			snd_sfx_play(SAMPLE_SELECT, 160, 128);
		}

		last_cond = cond;

	}
/*	pvr_mem_free(title_txr);
	return 0;
	*/
	/* NOTREACHED */

}

void draw_title(float a) {
	pvr_vertex_t vert;
	float x = 0.0f, y = 0.0f, z = 100.0f;
	float dx = 640.0f, dy = 480.0f;
	float r = a, g = a, b = a;

	vert.flags = PVR_CMD_VERTEX;
	vert.x = x;
	vert.y = y + dy;
	vert.z = z;
	vert.u = 0.0f;
	vert.v = dy / 512.0f;
	/* Though the polygon is opaque, we can fade it out
	 * by modifying the rgb vertex values, rather than alpha. */
	vert.argb = PVR_PACK_COLOR(1.0f, r, g, b);
	vert.oargb = 0;
	pvr_prim(&vert, sizeof(vert));
	
	vert.y = y;
	vert.v = 0.0f;
	pvr_prim(&vert, sizeof(vert));
	
	vert.x = x + dx;
	vert.y = y + dy;
	vert.u = dx / 1024.0f;
	vert.v = dy / 512.0f;
	pvr_prim(&vert, sizeof(vert));

	vert.flags = PVR_CMD_VERTEX_EOL;
	vert.y = y;
	vert.v = 0.0f;
	pvr_prim(&vert, sizeof(vert));
}


void title_render(float a) {
	static int ballsel_pos[MENU_CHOICES] = { 314, 348, 382, 416 };
	vid_border_color(0,0,0);
	pvr_wait_ready();
	pvr_scene_begin();

	pvr_list_begin(PVR_LIST_OP_POLY);
	/* title screen */
	pvr_prim(&title_header, sizeof(title_header));
	draw_title(a);
	
	pvr_list_finish();

	pvr_list_begin(PVR_LIST_TR_POLY);
	/* ball selector */
	pvr_prim(&ballsel_header, sizeof(ballsel_header));
	draw_poly_box(250,ballsel_pos[menu_choice],16,16,200,1,a,a,a);
	
	if (cht) {
		pvr_prim(&cht_header, sizeof(cht_header));
		draw_poly_box(280,380,128,32,200,1,a,a,a);
	}

	pvr_list_finish();

	pvr_scene_finish();
}
